const express = require("express");
const multer = require("multer");
const pdf = require("pdf-parse");
const fs = require('fs');

const app = express();
app.use(express.json());
app.use(express.urlencoded({extended: true}));
app.use((req, res, next) => {
  res.setHeader("Access-Control-Allow-Origin", "http://localhost:4200");
  res.setHeader("Access-Control-Allow-Methods", "GET, POST, OPTIONS");
  res.setHeader("Access-Control-Allow-Headers", "Content-Type, x-requested-with");
  next();
});

const storage = multer.diskStorage({
  destination: function (req, file, cb) {
    cb(null, "uploads/");
  },
  filename: function (req, file, cb) {
    cb(null, file.originalname);
  }
});

const upload = multer({storage: storage});

app.post("/upload", upload.single("file"), (req, res) => {
  try {
    const filePath = req.file.path;
    let dataBuffer = fs.readFileSync(filePath);
    pdf(dataBuffer).then(function (data) {
      // number of pages
      console.log(data.numpages);
      console.log("-------------------------------")
      // number of rendered pages
      console.log(data.numrender);
      // PDF info
      console.log("-------------------------------")

      console.log(data.info);
      console.log("-------------------------------")

      // PDF metadata
      console.log(data.metadata);
      console.log("-------------------------------")


      // PDF text
      console.log(data.text);
      console.log("-------------------------------")

    });
  } catch (error) {
    res.status(500).json({error: error.message});
  }
});

app.listen(3000, () => {
  console.log("Server started on port 3000");
});
